@@ -29,7 +29,7 @@ def plot(argv=None):
 
         plt.plot(d["time"], temperature_data, label=d["name"])
 
-    plt.legend()
+    matplotx.line_labels()
 
     if args.delta_t:
         plot_yaxis_label = "Δ temperature [°C over ambient]"
